@@ -1,4 +1,4 @@
-bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior = "horseshoe", penalize = NULL, block_vec = NULL, sigma = NULL, s2 = 1, kap2 = 1, N = 20000L, burnin = 0L, thinning = 1L, vglobal = 1, verb = FALSE, standardize = TRUE, singular = FALSE, scale_sigma_prior = TRUE, prior_mean = NULL, prob_vec = NULL, cc = NULL, ...){
+bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior = "horseshoe", penalize = NULL, block_vec = NULL, sigma = NULL, s2 = 1, kap2 = 1, N = 20000L, burnin = 0L, thinning = 1L, vglobal = 1, sampling_vglobal = TRUE, verb = FALSE, standardize = TRUE, singular = FALSE, scale_sigma_prior = TRUE, prior_mean = NULL, prob_vec = NULL, cc = NULL, ...){
 
 
     if (!inherits(formula, "formula"))
@@ -98,13 +98,13 @@ bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior
 
     if(prior == "horseshoe"){
         cat("horseshoe prior \n")
-        output = horseshoe_cpp_loop(Y, X, penalize, block_vec, prior_type, user_prior_function, sigma, s2, kap2, N, burnin, thinning, vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
+        output = horseshoe_cpp_loop(Y, X, penalize, block_vec, prior_type, user_prior_function, sigma, s2, kap2, N, burnin, thinning, vglobal, sampling_vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
     }else if(prior == "laplace"){
         cat("laplace prior \n")
-        output = blasso_cpp_loop(Y, X, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
+        output = blasso_cpp_loop(Y, X, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, sampling_vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
     }else if(prior == "ridge"){
         cat("ridge prior \n")
-        output = bridge_cpp_loop(Y, X, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
+        output = bridge_cpp_loop(Y, X, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, sampling_vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
     }else if(prior == "nonlocal"){
         cat("nonlocal prior \n")
         if(is.null(prior_mean) == TRUE){
@@ -115,7 +115,7 @@ bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior
                 prior_mean = rep(0, dim(X)[2])
             }
         }
-        output = nonlocal_cpp_loop(Y, X, prior_mean, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
+        output = nonlocal_cpp_loop(Y, X, prior_mean, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, sampling_vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
     }else if(prior == "sharkfin"){
         cat("sharkfin prior \n")
         if(is.null(prob_vec) == TRUE){
@@ -126,7 +126,7 @@ bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior
                 prob_vec = rep(0, dim(X)[2])
             }
         }
-        output = sharkfin_cpp_loop(Y, X, prob_vec, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
+        output = sharkfin_cpp_loop(Y, X, prob_vec, penalize, block_vec, prior_type, sigma, s2, kap2, N, burnin, thinning, vglobal, sampling_vglobal, verb, icept, standardize, singular, scale_sigma_prior, cc)
     }else{
         cat("wrong prior \n")
     }
@@ -139,16 +139,18 @@ bayeslm.formula <- function(formula, data = list(), Y = FALSE, X = FALSE, prior
     }
     residuals = Y - fittedvalue
 
-    attributes(output$sigma)$class = c("mcmc")
-    attributes(output$vglobal)$class = c("mcmc")
-    attributes(output$beta)$class = c("mcmc")
+    attributes(output$sigma)$class = c("MCMC", "matrix")
+    attributes(output$vglobal)$class = c("MCMC", "matrix")
+    attributes(output$beta)$class = c("MCMC", "matrix")
     attributes(output)$class = c("bayeslm.fit")
     colnames(output$beta) = Xnames
     colnames(output$sigma) = "sigma"
+    output$terms = terms(formula)
     
     output$call = this.call
     output$fitted.value = fittedvalue
     output$residuals = residuals
+    output$icept = icept
 
     return(output)
 }
\ No newline at end of file
