@@ -8,7 +8,7 @@ blocked elliptical slice sampler, ridge prior
 */
 
 // [[Rcpp::export]]
-List ridge(arma::mat Y, arma::mat X, arma::uvec penalize, arma::vec block_vec, int prior_type = 1, double sigma = 0.5, double s2 = 4, double kap2 = 16,  int nsamps = 10000, int burn = 1000, int skip = 1, double vglobal = 1, bool verb = false, bool icept = false, bool standardize = true, bool singular = false, bool scale_sigma_prior = true, arma::vec cc = NULL){
+List ridge(arma::mat Y, arma::mat X, arma::uvec penalize, arma::vec block_vec, int prior_type = 1, double sigma = 0.5, double s2 = 4, double kap2 = 16,  int nsamps = 10000, int burn = 1000, int skip = 1, double vglobal = 1.0, bool sampling_vglobal = true, bool verb = false, bool icept = false, bool standardize = true, bool singular = false, bool scale_sigma_prior = true, arma::vec cc = NULL){
 
     auto t0 = std::chrono::high_resolution_clock::now();
 
@@ -31,11 +31,14 @@ List ridge(arma::mat Y, arma::mat X, arma::uvec penalize, arma::vec block_vec, i
         sdy = 1.0;
         sdx.fill(1.0);
     }
+
+    arma::vec X_mean(X.n_cols);
     
     // intercepts
     if(icept == true){
         // if add a column of ones for intercept
         if(standardize == true){
+            X_mean = arma::mean(X, 0).t();
             X = scaling(X);
             Y = Y / sdy;
         }
@@ -239,13 +242,16 @@ List ridge(arma::mat Y, arma::mat X, arma::uvec penalize, arma::vec block_vec, i
         }
         
 
-        // update the global shrinkage parameter
-        vgprop = exp(log(vglobal) + arma::as_scalar(randn(1)) * 0.05);
+        if(sampling_vglobal){
+            // update the global shrinkage parameter
+            vgprop = exp(log(vglobal) + arma::as_scalar(randn(1)) * 0.2);
+            // if there is no intercept, pass the full vector
+            ratio = exp(log_horseshoe_approx_prior(b, vgprop, s, penalize, scale_sigma_prior) - log_horseshoe_approx_prior(b, vglobal, s, penalize, scale_sigma_prior) + log(vgprop) - log(vglobal));
 
-        ratio = exp(log_ridge_prior(b, lambda, vgprop, s, penalize, scale_sigma_prior) + log_normal_density(vgprop, 0.0, 100.0)  - log_ridge_prior(b, lambda, vglobal, s, penalize, scale_sigma_prior) - log_normal_density(vglobal, 0.0, 100.0)  +log(vgprop) - log(vglobal));
 
-        if(as_scalar(randu(1)) < ratio){
-            vglobal = vgprop;
+            if(as_scalar(randu(1)) < ratio){
+                vglobal = vgprop;
+            }
         }
 
 
@@ -287,6 +293,13 @@ List ridge(arma::mat Y, arma::mat X, arma::uvec penalize, arma::vec block_vec, i
         bsamps.col(ll) = bsamps.col(ll) / trans(sdx) * sdy;
     }
 
+    // adjust intercept if standardize all X variables
+    if(icept && standardize){
+        for(size_t ll = 0; ll < bsamps.n_cols; ll ++ )
+        {   
+            bsamps(0, ll) = bsamps(0, ll) - arma::sum(bsamps.submat(1, ll, p-1, ll) % X_mean);
+        }            
+    }
 
     ssamps = ssamps * sdy;
 
